%global __python %{__python3}

Name:		znc
Version:	1.7.4
Release:	%mkrel 1
License:	GPLv2+
Summary:	An IRC bouncer with many advanced features
Group:		Networking/IRC
URL:		https://wiki.znc.in/ZNC
Source0:	http://znc.in/releases/%{name}-%{version}.tar.gz


BuildRequires:		systemd-units
Requires(pre):		shadow-utils
Requires(post):		systemd-units
Requires(preun):	systemd-units
Requires(postun):	systemd-units

BuildRequires:		cmake
BuildRequires:		swig
BuildRequires:		boost-devel
BuildRequires:		gettext-devel
BuildRequires:		icu-devel
BuildRequires:		perl-devel
BuildRequires:		perl(ExtUtils::Embed)
BuildRequires:		pkgconfig(libcares)
BuildRequires:		pkgconfig(libsasl2)
BuildRequires:		pkgconfig(openssl) >= 1.1
BuildRequires:		pkgconfig(python3)
BuildRequires:		pkgconfig(tcl)
BuildRequires:		pkgconfig(systemd)
BuildRequires:		pkgconfig(zlib)

Obsoletes:		znc-extra <= %{version}-%{release}

%description
ZNC is an IRC bouncer with many advanced features like detaching,
multiple users, per channel playback buffer, SSL, IPv6, transparent
DCC bouncing, Perl and C++ module support to name a few.

%package devel
Summary:	Development files needed to compile ZNC modules
Group:		Development/C
Requires:	%{name} = %{version}-%{release}

%description devel
All includes and program files you need to compile your own znc
modules.

%package modperl
Summary:	perl module for ZNC
Group:		Development/Perl
Requires:	%{name} = %{version}-%{release}
Requires:	perl
Provides:	perl(ZNC::Module) = %{version}-%{release}

%description modperl
perl module for ZNC.

%package modpython
Summary:	python3 module for ZNC
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Requires:	python3

%description modpython
python3 module for ZNC.

%prep
%setup -q

%build
%cmake \
	-DWANT_IPV6=1 \
	-DWANT_PYTHON=1 \
	-DWANT_PERL=1 \
	-DWANT_TCL=1 \
	-DWANT_CYRUS=1 \
	-DWANT_SYSTEMD=1 \
	-DSYSTEMD_DIR=%{_unitdir} \
	-DWANT_PYTHON_VERSION=python3 \
	-DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed"
%make_build

%pre
getent group znc >/dev/null || groupadd -r znc
getent passwd znc >/dev/null || \
    useradd -r -g znc -d /var/lib/znc -s /sbin/nologin \
    -c "Account for ZNC to run as" znc
mkdir -p /var/lib/znc
chown znc:znc /var/lib/znc
#exit 0

%install
%make_install -C build

%find_lang %{name} --all-name

%post
%_post_service %{name}

%preun
%_preun_service %{name}


%files -f %{name}.lang
%doc ChangeLog.md NOTICE README.md
%license LICENSE
%{_libdir}/%{name}/
%exclude %{_libdir}/%{name}/modperl*
%exclude %{_libdir}/%{name}/perleval.pm
%exclude %{_libdir}/%{name}/modpython*
%{_bindir}/znc
%{_datadir}/znc/
%{_unitdir}/znc.service
%{_mandir}/man1/znc-buildmod.1.*
%{_mandir}/man1/znc.1.*

%files devel
%doc ChangeLog.md NOTICE README.md
%{_bindir}/znc-buildmod
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/znc/

%files modperl
%doc ChangeLog.md NOTICE README.md
%{_libdir}/znc/modperl/
%{_libdir}/znc/modperl.so
%{_libdir}/znc/perleval.pm

%files modpython
%doc ChangeLog.md NOTICE README.md
%{_libdir}/znc/modpython/
%{_libdir}/znc/modpython.so


%changelog
* Mon Aug 12 2019 shlomif <shlomif> 1.7.4-1.mga7
+ Revision: 1428867
- New version 1.7.4 - security fix for MGA#23327

* Sun Apr 14 2019 daviddavid <daviddavid> 1.7.3-1.mga7
+ Revision: 1390016
- new version: 1.7.3
- switch to cmake build system
- enable i18n support
- use upstream systemd unit file

* Sat Feb 02 2019 shlomif <shlomif> 1.7.2-1.mga7
+ Revision: 1362461
- New version 1.7.2

* Thu Jan 10 2019 daviddavid <daviddavid> 1.7.1-4.mga7
+ Revision: 1354079
- rebuild for new Python 3.7

* Mon Sep 24 2018 tv <tv> 1.7.1-3.mga7
+ Revision: 1303436
- do byte compile python3 now that rpm-mageia-setup is fixed

* Wed Aug 29 2018 tv <tv> 1.7.1-2.mga7
+ Revision: 1255551
- stop failing the build when python bytecompiling fails
+ daviddavid <daviddavid>
- rebuild for new perl 5.28.0

* Wed Jul 18 2018 shlomif <shlomif> 1.7.1-1.mga7
+ Revision: 1244168
- New version 1.7.1 - MGA#23327 .

* Thu May 10 2018 shlomif <shlomif> 1.7.0-1.mga7
+ Revision: 1228126
- New version 1.7.0

* Tue Apr 03 2018 shlomif <shlomif> 1.6.6-1.mga7
+ Revision: 1215086
- New version 1.6.6

* Fri Dec 29 2017 wally <wally> 1.6.5-2.mga7
+ Revision: 1187025
- rebuild for new icu

* Sat Sep 02 2017 daviddavid <daviddavid> 1.6.5-1.mga7
+ Revision: 1150666
- new version: 1.6.5
- enable tcl and cyrus support
- update URL
- exclude modpython from main package
- rebuild for new Python 3.6

* Sat Jul 22 2017 neoclust <neoclust> 1.6.3-5.mga7
+ Revision: 1127201
- Rebuild against new Perl 5.26

* Wed Apr 05 2017 neoclust <neoclust> 1.6.3-4.mga6
+ Revision: 1095959
- Rebuild for armv7

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 1.6.3-3.mga6
+ Revision: 1092817
- Rebuild for icu-58.2

* Tue Oct 18 2016 wally <wally> 1.6.3-2.mga6
+ Revision: 1061835
- BR icu

* Thu Mar 10 2016 shlomif <shlomif> 1.6.3-1.mga6
+ Revision: 988715
- New version 1.6.3 (MGA#17938)

* Thu Mar 03 2016 umeabot <umeabot> 1.4-12.mga6
+ Revision: 984783
- Rebuild for openssl

* Wed Feb 17 2016 umeabot <umeabot> 1.4-11.mga6
+ Revision: 963703
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 tv <tv> 1.4-10.mga6
+ Revision: 887732
- rebuild for python 3.5

* Thu Oct 08 2015 daviddavid <daviddavid> 1.4-9.mga6
+ Revision: 887687
- rebuild for python 3.5

* Sat Jun 27 2015 tv <tv> 1.4-8.mga6
+ Revision: 845992
- rebuild with soname-ified perl

* Wed Feb 18 2015 luigiwalser <luigiwalser> 1.4-7.mga5
+ Revision: 815588
- use correct service scriplet macros for mageia

* Wed Oct 15 2014 umeabot <umeabot> 1.4-6.mga5
+ Revision: 744572
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.4-5.mga5
+ Revision: 730758
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.4-4.mga5
+ Revision: 690883
- Mageia 5 Mass Rebuild

* Sun Jun 08 2014 pterjan <pterjan> 1.4-3.mga5
+ Revision: 634835
- Rebuild for new python

* Wed May 21 2014 shlomif <shlomif> 1.4-2.mga5
+ Revision: 624755
- New group
- Fix groups (thanks to roelof)
- Remove trailing whitespace
- New version 1.4 - thanks to roelof (my apprentice)

* Thu Apr 24 2014 luigiwalser <luigiwalser> 1.0-5.mga5
+ Revision: 617588
- rediff patch from fedora to fix potential crash bug when adding channels

* Sat Oct 19 2013 umeabot <umeabot> 1.0-4.mga4
+ Revision: 532356
- Mageia 4 Mass Rebuild

* Mon Aug 19 2013 luigiwalser <luigiwalser> 1.0-3.mga4
+ Revision: 467981
- add upstream patch to fix CVE-2013-2130

* Mon Jan 14 2013 umeabot <umeabot> 1.0-2.mga3
+ Revision: 387770
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 28 2012 shikamaru <shikamaru> 1.0-1.mga3
+ Revision: 322715
- new version 1.0, fix file list

* Thu Jun 07 2012 solbu <solbu> 0.206-1.mga3
+ Revision: 256653
- Fix description and summary - bounce -> bouncer
- New version
- Spec cleanup

* Wed Apr 13 2011 shikamaru <shikamaru> 0.098-1.mga1
+ Revision: 84739
- new version 0.098 - fix file list

* Thu Jan 27 2011 erwan <erwan> 0.096-1.mga1
+ Revision: 42206
- imported package znc

